=========
pyhelpers
=========


Some tiny helper classes for daily routines


Description
===========

Personal collection of python helper classes (e.g. timer with context, string (list) formats, logging configs, base config class


Note
====

This project has been set up using PyScaffold 3.0.3. For details and usage
information on PyScaffold see http://pyscaffold.org/.
